/*********************************************************************/
/*                                                                   */
/*   Program Name :  signalcheck                                     */
/*                                                                   */
/*      Version:  0.00  2002-10-04                                   */
/*                0.10  2002-10-04                                   */
/*                1.13  2005-09-28   support linux2                  */
/*                2.00  2005-12-20  support VSSP32                   */
/*                2.10  2007-02-23  revised to use common library    */
/*                2.11  2007-08-23  add FPGA version display         */
/*                                                                   */
/*      Copyright (c) 2002-2007  T.Kondo/NICT All Right Reserved     */
/*                                                                   */
/*********************************************************************/
/*
/*
     Signalcheck checks whether 10MHz and 1PPS is supplied to a K5/VSSP or K5/VSSP32
     or not. FPGA version is also displayed in case of VSSP32 of which Version after 2007-08-17
     
        How to use
             signalcheck


*/
#define PROGRAM_VERSION "Ver. 2007-08-23"
#include "chead.h"      // common header for IP-VLBI utilities
#include "libipvlbi_board.h"  // library for IP-VLBI sampler board

int main(int argc, char **argv)
{
    //char dev[] = "/dev/tds0";
    char dev[] = DEV_FILE;
    int fd_in,rv;
    unsigned int stat;
    unsigned int ref, pps, rhz;
#ifdef _VSSP32
    struct tdsio tdsio;    // 2007-08-23
#endif
    
    printf("\n signalcheck (%s)\n",PROGRAM_VERSION);

#ifdef _VSSP32
    printf("\n  K5/VSSP32 (IP-VLBI) board Reference and 1PPS signal checking..\n\n");
#else
    printf("\n  K5/VSSP (IP-VLBI) board 10MHz and 1PPS signal checking..\n\n");
#endif
    fd_in = open(dev, O_RDONLY);
    if (fd_in == -1) {
        perror("device open() error ");
        return -1;
    }

    /* board reference signal check */
    stat=board_ref_check(fd_in);
    if((stat & 0x10) == 0x10){ // this is VSSP32
        if((stat & 1) != 1){
            printf("   Warning! 10MHz or 5MHz signal is not supplied. \n");
        } else {
            if((stat & 4) == 4){
                printf("   Reference (5MHz) signal is OK!");
            } else {
                printf("   Reference (10MHz) signal is OK!");
            }
            if((stat & 8) == 8){
                printf("   PLL locked!\n");
            } else {
                printf("   Warning! PLL unlocked!\n");
            }
        }
    } else {   // this is VSSP
        if((stat & 1) != 1){
            printf("   Warning! 10MHz signal is not supplied. \n");
        } else {
            printf("   10MHz signal is OK!\n");
        }
    }
    if((stat & 2) != 2){
        printf("   Warning! 1PPS signal is not supplied. \n");
    } else {
        printf("   1PPS  signal is OK!\n");
    }
    if((stat & 3) == 0 || (stat & 3) == 2){
       printf("   Check signal connection and try again!\n");
       goto end;
    }
end:

#ifdef _VSSP32  // just for the case of VSSP32 only
#ifndef _VSSP32_OLD_DRIVER
    
    /* get FPGA version */    // added on 2007-08-23   driver should be 2007-08-17 or later
    
    if((rv=ioctl(fd_in, TDSIO_GET_VERFPGA, &tdsio)) == -1){
        //perror(" ioctl() GET VER FPGA failed ");  
    } else {
        printf("\n   VSSP32 FPGA Version = %d.%02d\n" ,(tdsio.value >> 6), (tdsio.value & 0x3F));
    }
    // add end 2007-08-23
#endif
#endif

    printf("\n");
    close(fd_in);

}
